<?php
/**
 * @file
 * Default theme implementation for the kss styleguide.
 *
 * Available variables:
 * - attributes: HTML attributes for the wrapper.
 * - kss_sections: An array of all sections
 *
 * @see template_preprocess_kss_styleguide()
 *
 * @ingroup themeable
 */
?>
<div class="layout-kss">

  <nav class="layout-kss__sidebar">
    <!-- <h2 class="visually-hidden">Styleguide Navigation</h2> -->
    <ul class="kssmenu">
      <?php foreach ($kss_sections as $section): ?>
        <li class="kssmenu__item"><a href="#kss-section-<?php print $section->getTitle(); ?>"><?php print $section->getTitle(); ?></a></li>
      <?php endforeach; ?>
    </ul>
  </nav>

  <div class="layout-kss__main">
    <?php foreach ($kss_sections as $section): ?>

      <section class="kss" id="kss-section-<?php print $section->getTitle(); ?>">

        <header class="kss__header">
          <h3 class="kss__title"><?php print $section->getTitle(); ?></h3>
          <div class="kss__file">
            <?php print $section->getfileName(); ?>
            (<?php print $section->getreference(); ?>)
          </div>
        </header>

        <article class="kss__main">

          <div class="kss__description">
            <?php print $section->getDescription(); ?>
          </div>

          <div class="kss__status">
            <?php if ($section->getdeprecated()): ?>
              <div class="kss__deprecated"><b>Deprecated</b>: <?php print $section->getdeprecated(); ?></div>
            <?php endif; ?>

            <?php if ($section->getexperimental()): ?>
              <div class="kss__experimental"><b>Experimental</b>: <?php print $section->getexperimental(); ?></div>
            <?php endif; ?>

            <?php if ($section->getcompatibility()): ?>
              <div class="kss__compatibility"><b>Compatibility</b>: <?php print $section->getcompatibility(); ?></div>
            <?php endif; ?>
          </div>


        </article>

        <?php if ($section->getMarkup() != ''): ?>
          <article class="kss__selector">
            <div class="kss__example">
              <?php print $section->getMarkup(); ?>
            </div>
          </article>
        <?php endif; ?>

        <?php if ($modifiers = $section->getModifiers()): ?>
          <?php foreach ($modifiers as $modifier): ?>
            <article class="kss__selector">

              <header class="kss__selector-header">
                <h3 class="kss__name"><?php print $modifier->getName(); ?></h3>

                <?php if ($modifier->getDescription() != ''): ?>
                  <div class="kss__info">
                    <?php print $modifier->getDescription(); ?>
                  </div>
                <?php endif; ?>

                <?php if ($modifier->getExtendedClass()): ?>
                  <span class="kss__extended">
                    @extend <?php print $modifier->getExtendedClass(); ?>
                  </span>
                <?php endif; ?>
              </header>

              <?php if ($modifier->getExampleHtml()): ?>
              <div class="kss__example">
                <?php print $modifier->getExampleHtml(); ?>
              </div>
              <?php endif; ?>

            </article>
          <?php endforeach; ?>
        <?php endif; ?>

        <?php if ($section->getMarkup()): ?>
          <article class="kss__markup">
            <pre><code class="language-html"><?php print check_plain($section->getMarkup()); ?></code></pre>
          </article>
        <?php endif; ?>

      </section>

    <?php endforeach; ?>
  </div>
</div>
